from local_config import local_options

from pyeasyphd.scripts import run_generate_c_yearly

if __name__ == "__main__":
    options = {
        "include_publisher_list": [],
        "include_abbr_list": [],
        "exclude_publisher_list": ["arXiv"],
        "exclude_abbr_list": [],
    }

    path_yearly_docs = local_options["path_yearly_docs"]
    keywords_category_names = ["", "S", "Y"]
    path_spidered_bibs = local_options["path_spidered_bibs"]
    path_conf_j_jsons = local_options["path_conf_j_jsons"]
    year_list = []

    run_generate_c_yearly(
        options, path_yearly_docs, keywords_category_names, path_spidered_bibs, path_conf_j_jsons, year_list
    )



from local_config import local_options

from pyeasyphd.scripts import (
    run_generate_j_e_weekly,
    run_generate_j_monthly,
    run_generate_j_weekly,
    run_generate_j_yearly,
)

if __name__ == "__main__":
    options = {
        "include_publisher_list": [],
        "include_abbr_list": [],
        "exclude_publisher_list": ["arXiv"],
        "exclude_abbr_list": [],
    }

    path_weekly_docs = local_options["path_weekly_docs"]
    path_monthly_docs = local_options["path_monthly_docs"]
    path_yearly_docs = local_options["path_yearly_docs"]
    keywords_category_names = ["", "S", "Y"]
    path_spidered_bibs = local_options["path_spidered_bibs"]
    path_spidering_bibs = local_options["path_spidering_bibs"]
    path_conf_j_jsons = local_options["path_conf_j_jsons"]

    # for IEEE Early Access
    run_generate_j_e_weekly(options, path_weekly_docs, keywords_category_names, path_spidering_bibs, path_conf_j_jsons)

    # for weekly papers
    run_generate_j_weekly(options, path_weekly_docs, keywords_category_names, path_spidering_bibs, path_conf_j_jsons)

    # for monthly papers
    run_generate_j_monthly(options, path_monthly_docs, keywords_category_names, path_spidering_bibs, path_conf_j_jsons)

    # for yearly papers
    year_list = []
    run_generate_j_yearly(
        options, path_yearly_docs, keywords_category_names, path_spidered_bibs, path_conf_j_jsons, year_list
    )



from local_config import local_options

from pyeasyphd.scripts import run_compare_bib_with_zotero

if __name__ == "__main__":
    zotero_bib = local_options["zotero_bib"]
    path_output = local_options["path_output"]
    path_conf_j_jsons = local_options["path_conf_j_jsons"]

    options = {}
    need_compare_bib = "/path/to/need_compare.bib"

    run_compare_bib_with_zotero(options, need_compare_bib, zotero_bib, path_output, path_conf_j_jsons)



import os

from local_config import local_options

from pyeasyphd.scripts import run_compare_bib_with_local, run_format_bib_to_abbr_zotero_save

if __name__ == "__main__":
    path_output = local_options["path_output"]
    path_spidered_bibs = local_options["path_spidered_bibs"]
    path_spidering_bibs = local_options["path_spidering_bibs"]
    path_conf_j_jsons = local_options["path_conf_j_jsons"]

    options = {
        "include_publisher_list": [],
        "include_abbr_list": [],
        "exclude_publisher_list": ["arXiv"],
        "exclude_abbr_list": [],
        "compare_each_entry_with_all_local_bibs": False,
    }
    need_compare_bib = "/path/to/need_compare.bib"

    run_compare_bib_with_local(
        options, need_compare_bib, path_output, path_spidered_bibs, path_spidering_bibs, path_conf_j_jsons
    )

    name = "in_local_entries"
    options.update(
        {
            "bib_name_for_abbr": f"{name}_abbr.bib",
            "bib_name_for_zotero": f"{name}_zotero.bib",
            "bib_name_for_save": f"{name}_save.bib",
        }
    )
    run_format_bib_to_abbr_zotero_save(
        options, os.path.join(path_output, f"{name}.bib"), path_output, path_conf_j_jsons
    )



import os

from local_config import local_options

from pyeasyphd.scripts import run_compare_after_search, run_format_bib_to_abbr_zotero_save, run_search_for_files

if __name__ == "__main__":
    path_main_output = local_options["path_output"]
    path_spidered_bibs = local_options["path_spidered_bibs"]
    path_spidering_bibs = local_options["path_spidering_bibs"]
    path_conf_j_jsons = local_options["path_conf_j_jsons"]
    zotero_bib = local_options["zotero_bib"]

    _h_ = "(?:| |-)"  # hyphen

    keywords_type = "Landscape Analysis"
    keywords_list_list = [
        [r"landscape(?:|s) analysis"],
        [r"fitness landscape(?:|s)"],
        [[r"landscape(?:|s)", "analysis"], [r"landscape(?:|s) analysis"]],
        [["fitness", r"landscape(?:|s)"], [r"fitness landscape(?:|s)"]],
        [[r"landscape(?:|s)"], ["analysis", "fitness"]],
    ]

    keywords_type = "DMOO"
    keywords_list_list = [
        [f"dynamic evolutionary multi{_h_}objective"],
        [f"dynamic multi{_h_}objective"],
        [f"dynamic evolutionary many{_h_}objective"],
        [f"dynamic many{_h_}objective"],
        [f"dynamic evolutionary constrained multi{_h_}objective"],
        [f"dynamic constrained multi{_h_}objective"],
        [f"dynamic evolutionary constrained many{_h_}objective"],
        [f"dynamic constrained many{_h_}objective"],
    ]

    keywords_type = "PS"
    keywords_list_list = [["reversible jump markov chain monte carlo"], ["reversible jump MCMC"]]

    # Configurations
    search_in_spidered_bibs = False
    search_in_spidering_bibs = True
    options = {
        "include_publisher_list": [],
        "include_abbr_list": [],
        "exclude_publisher_list": ["arXiv"],
        "exclude_abbr_list": [],
    }

    # search
    run_search_for_files(
        keywords_type,
        keywords_list_list,
        path_main_output,
        path_spidered_bibs,
        path_spidering_bibs,
        path_conf_j_jsons,
        search_in_spidered_bibs,
        search_in_spidered_bibs,
        options,
    )

    # compare
    run_compare_after_search(zotero_bib, keywords_type, path_main_output, path_conf_j_jsons)

    # format
    need_format_bib = os.path.join(path_main_output, "Compared", "only_in_download.bib")
    path_output = os.path.join(path_main_output, "Formatted")
    run_format_bib_to_abbr_zotero_save(options, need_format_bib, path_output, path_conf_j_jsons)
